@@ -1,7 +1,7 @@
-/*
+  /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2009 Sampo Savola, Jukka Alasalmi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -202,7 +202,7 @@ ActivityDescription *activity_chooser_choose_activity(ActivityChooser *self)
 	do {
 		response = gtk_dialog_run(GTK_DIALOG(chooser_dialog->dialog));
 
-		if(response == GTK_RESPONSE_CANCEL)
+		if(response == GTK_RESPONSE_DELETE_EVENT)
 		{
 			activity_chooser_dialog_destroy(chooser_dialog);
 			DEBUG_END();
@@ -211,6 +211,7 @@ ActivityDescription *activity_chooser_choose_activity(ActivityChooser *self)
 		file_name = activity_chooser_dialog_choose_file_name(
 					self,
 					chooser_dialog);
+
 	} while(!file_name);
 
 	activity_description = activity_description_new(
@@ -223,9 +224,12 @@ ActivityDescription *activity_chooser_choose_activity(ActivityChooser *self)
 
 	activity_description->file_name = file_name;
 
-	activity_description->heart_rate_range_id = gtk_combo_box_get_active(
-			GTK_COMBO_BOX(chooser_dialog->cmb_pulse_ranges));
 
+//	  activity_description->heart_rate_range_id = gtk_combo_box_get_active(
+//			GTK_COMBO_BOX(chooser_dialog->cmb_pulse_ranges));
+
+      activity_description->heart_rate_range_id = hildon_picker_button_get_active (chooser_dialog->button);
+      DEBUG("HR RANGE ID SELECTED: %d", activity_description->heart_rate_range_id);
 	exercise_description = &self->heart_rate_settings->
 		exercise_descriptions[activity_description->
 		heart_rate_range_id];
@@ -234,8 +238,20 @@ ActivityDescription *activity_chooser_choose_activity(ActivityChooser *self)
 		exercise_description->low;
 	activity_description->heart_rate_limit_high =
 		exercise_description->high;
+       DEBUG("%d",activity_description->heart_rate_limit_low);
+       DEBUG("%d",activity_description->heart_rate_limit_high);
+	if(hildon_check_button_get_active(HILDON_CHECK_BUTTON(
+					chooser_dialog->chk_add_calendar)))
+	{
 
-	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+	activity_description->add_calendar = TRUE;
+
+	}
+	else{
+
+	 activity_description->add_calendar = FALSE;
+	}
+	if(hildon_check_button_get_active(HILDON_CHECK_BUTTON(
 					chooser_dialog->chk_save_dfl)))
 	{
 		/* Save the default values */
@@ -276,7 +292,8 @@ gboolean activity_chooser_choose_and_setup_activity(ActivityChooser *self)
 				activity_description->activity_comment,
 				activity_description->file_name,
 				activity_description->heart_rate_limit_low,
-				activity_description->heart_rate_limit_high))
+				activity_description->heart_rate_limit_high,
+				   activity_description->add_calendar))
 	{
 		activity_description_free(activity_description);
 		DEBUG_END();
@@ -350,7 +367,9 @@ static ActivityChooserDialog *activity_chooser_dialog_new(
 	ActivityChooserDialog *chooser_dialog = NULL;
 	GtkWidget *vbox = NULL;
 	GtkWidget *caption = NULL;
+
 	GtkSizeGroup *size_group = NULL;
+
 	gint i;
 
 	g_return_val_if_fail(self != NULL, NULL);
@@ -369,7 +388,9 @@ static ActivityChooserDialog *activity_chooser_dialog_new(
 
 	size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
-	chooser_dialog->entry_activity_name = gtk_entry_new();
+
+
+	chooser_dialog->entry_activity_name = hildon_entry_new (HILDON_SIZE_AUTO);
 	if(self->default_activity_name)
 	{
 		gtk_entry_set_text(GTK_ENTRY(chooser_dialog->
@@ -382,14 +403,14 @@ static ActivityChooserDialog *activity_chooser_dialog_new(
 
 	caption = hildon_caption_new(
 			size_group,
-			_("Activity type"),
+			_("Activity name"),
 			chooser_dialog->entry_activity_name,
 			NULL,
 			HILDON_CAPTION_OPTIONAL);
 
 	gtk_box_pack_start(GTK_BOX(vbox), caption, FALSE, FALSE, 0);
-
-	chooser_dialog->entry_activity_comment = gtk_entry_new();
+/*
+	chooser_dialog->entry_activity_comment = hildon_entry_new (HILDON_SIZE_AUTO);
 
 	caption = hildon_caption_new(
 			size_group,
@@ -399,41 +420,42 @@ static ActivityChooserDialog *activity_chooser_dialog_new(
 			HILDON_CAPTION_OPTIONAL);
 
 	gtk_box_pack_start(GTK_BOX(vbox), caption, FALSE, FALSE, 0);
-
+*/
+	/*
 	chooser_dialog->cmb_pulse_ranges = gtk_combo_box_new_text();
 
-	for(i = 0; i < EC_EXERCISE_TYPE_COUNT; i++)
-	{
-		gtk_combo_box_append_text(
-				GTK_COMBO_BOX(chooser_dialog->cmb_pulse_ranges),
-				self->heart_rate_settings->
-				exercise_descriptions[i].name);
-	}
+
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(chooser_dialog->
 				cmb_pulse_ranges),
 			self->default_heart_rate_range_id);
 
-	caption = hildon_caption_new(
-			size_group,
-			_("Target heart rate type"),
-			chooser_dialog->cmb_pulse_ranges,
-			NULL,
-			HILDON_CAPTION_OPTIONAL);
+	*/
 
-	gtk_box_pack_start(GTK_BOX(vbox), caption, FALSE, FALSE, 0);
+	chooser_dialog->button = hildon_picker_button_new (HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+        hildon_button_set_title (HILDON_BUTTON (chooser_dialog->button), "Target heart rate type");
+	 chooser_dialog->selector = hildon_touch_selector_new_text ();
 
-	chooser_dialog->chk_save_dfl = gtk_check_button_new();
+	for(i = 0; i < EC_EXERCISE_TYPE_COUNT; i++)
+	{
 
-	caption = hildon_caption_new(
-			size_group,
-			_("Save as default"),
-			chooser_dialog->chk_save_dfl,
-			NULL,
-			HILDON_CAPTION_OPTIONAL);
+	hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (chooser_dialog->selector), self->heart_rate_settings->exercise_descriptions[i].name);
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (chooser_dialog->selector), 0, 0);
 
-	gtk_box_pack_start(GTK_BOX(vbox), caption, FALSE, FALSE, 0);
+	}
+       hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (chooser_dialog->button),HILDON_TOUCH_SELECTOR (chooser_dialog->selector));
 
+	gtk_box_pack_start(GTK_BOX(vbox), chooser_dialog->button, FALSE, FALSE, 0);
+
+	chooser_dialog->chk_save_dfl = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON ( chooser_dialog->chk_save_dfl), "Save as default");
+
+	gtk_box_pack_start(GTK_BOX(vbox), chooser_dialog->chk_save_dfl, FALSE, FALSE, 0);
+
+	 chooser_dialog->chk_add_calendar = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (chooser_dialog->chk_add_calendar), "Add to calendar");
+	 hildon_check_button_set_active(GTK_BUTTON ( chooser_dialog->chk_add_calendar),TRUE);
+	gtk_box_pack_start(GTK_BOX(vbox),chooser_dialog->chk_add_calendar, FALSE, FALSE, 0);
 	DEBUG_END();
 	return chooser_dialog;
 }
@@ -462,11 +484,13 @@ static gchar *activity_chooser_dialog_choose_file_name(
 	gchar *date_str = NULL;
 	gchar *dfl_fname = NULL;
 	gint result;
-
+	gint i = 1;
 	g_return_val_if_fail(self != NULL, NULL);
 	g_return_val_if_fail(chooser_dialog != NULL, NULL);
 	DEBUG_BEGIN();
-
+	gchar* extension;
+	extension = g_strdup_printf(".gpx");
+	
 	activity_name = gtk_entry_get_text(
 			GTK_ENTRY(chooser_dialog->entry_activity_name));
 
@@ -474,9 +498,9 @@ static gchar *activity_chooser_dialog_choose_file_name(
 
 	if(strcmp(activity_name, "") == 0)
 	{
-		dfl_fname = g_strdup_printf("%s.gpx", date_str);
+		dfl_fname = g_strdup_printf("%s", date_str);
 	} else {
-		dfl_fname = g_strdup_printf("%s-%s.gpx", date_str,
+		dfl_fname = g_strdup_printf("%s-%s", date_str,
 				activity_name);
 	}
 
@@ -493,13 +517,6 @@ static gchar *activity_chooser_dialog_choose_file_name(
 		DEBUG_END();
 		return NULL;
 	}
-
-	file_dialog = hildon_file_chooser_dialog_new_with_properties(
-			GTK_WINDOW(self->parent_window),
-			"file_system_model", fs_model,
-			"action", GTK_FILE_CHOOSER_ACTION_SAVE,
-			NULL);
-
 	gtk_file_chooser_set_current_folder(
 			GTK_FILE_CHOOSER(file_dialog),
 			self->default_folder_name);
@@ -508,29 +525,19 @@ static gchar *activity_chooser_dialog_choose_file_name(
 			GTK_FILE_CHOOSER(file_dialog),
 			dfl_fname);
 
-	g_free(dfl_fname);
-
-	gtk_widget_show_all(file_dialog);
-	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
-
-	if(result == GTK_RESPONSE_CANCEL)
+	file_name =  g_strdup_printf("%s/%s%s",self->default_folder_name,dfl_fname,extension);
+	DEBUG("%s",file_name);
+	while(g_file_test(file_name,G_FILE_TEST_EXISTS))
 	{
-		DEBUG_LONG("User cancelled the operation");
-		gtk_widget_destroy(file_dialog);
-		DEBUG_END();
-		return NULL;
+	g_free(file_name);
+	file_name =  g_strdup_printf("%s/%s-%d%s",self->default_folder_name,dfl_fname,i,extension);
+	DEBUG("%s",file_name);
+	i++;
 	}
-
-	gconf_helper_set_value_string(
-			self->gconf_helper,
-			ECGC_DEFAULT_FOLDER,
-			gtk_file_chooser_get_current_folder(
-				GTK_FILE_CHOOSER(file_dialog)));
-
-	file_name = gtk_file_chooser_get_filename(
-			GTK_FILE_CHOOSER(file_dialog));
-
-	gtk_widget_destroy(file_dialog);
+	gconf_helper_set_value_string_simple(self->gconf_helper,LAST_ACTIVITY,file_name);
+	g_free(extension);
+	g_free(dfl_fname);
+	
 	DEBUG_END();
 	return file_name;
 }
