@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2009 Sampo Savola  Jukka Alasalmi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -63,4 +63,13 @@
 
 #define DISPLAY_ON		ECGC_BASE_DIR "/display_on"
 
+#define USER_WEIGHT		ECGC_BASE_DIR "/user_weight"
+#define USER_HEIGHT		ECGC_BASE_DIR "/user_height"
+#define USER_AGE		ECGC_BASE_DIR "/user_age"
+#define GPS_INTERVAL		ECGC_BASE_DIR "/gps_interval"
+#define MAP_SOURCE		ECGC_BASE_DIR "/map_source"
+#define FIRST_BOOT		ECGC_BASE_DIR "/first_boot"
+#define NOTIFY_USER		ECGC_BASE_DIR "/notify_user"
+#define LAST_ACTIVITY		ECGC_BASE_DIR "/last_activity"
+
 #endif /* _GCONF_KEYS_H */
