@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi, Kai Skiftesvik
+ *  Copyright (C) 2008  Jukka Alasalmi, Kai Skiftesvik, Sampo Savola
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,10 +30,11 @@
 /* Hildon */
 #include <hildon/hildon-caption.h>
 #include <hildon/hildon-note.h>
-
+#include <hildon/hildon-text-view.h>
+#include <hildon/hildon-pannable-area.h>
 /* Other modules */
 #include "config.h"
-
+#include "calculate_bmi.h"
 #include "beat_detect.h"
 #include "gconf_keys.h"
 #include "navigation_menu.h"
@@ -43,7 +44,6 @@
 #include "settings.h"
 #include "general_settings.h"
 #include "target_heart_rate.h"
-#include "calculate_bmi.h"
 #include "calculate_maxheartrate.h"
 #include "util.h"
 
@@ -56,9 +56,9 @@
 #define RCFILE_PATH DATADIR "/" PACKAGE_NAME "/ec_style.rc"
 #define GFXDIR DATADIR "/pixmaps/" PACKAGE_NAME "/"
 
-const gchar * MAPTILELOADER_DBUS_SERVICE = "org.ecoach.maptileloader";
-const gchar * MAPTILELOADER_DBUS_OBJECT_PATH = "/org/ecoach/maptileloader";
-const gchar * MAPTILELOADER_DBUS_INTERFACE = "org.ecoach.maptileloader";
+const gchar * HILDON_DBUS_SERVICE = "com.nokia.hildon_desktop";
+const gchar * HIDLON_DBUS_OBJECT_PATH = "/com/nokia/hildon_desktop";
+const gchar * HILDON_DBUS_INTERFACE = "com.nokia.hildon_desktop";
 /*****************************************************************************
  * Private function prototypes                                               *
  *****************************************************************************/
@@ -80,7 +80,7 @@ static void interface_display_state_changed(
 		gpointer user_data_2);
 
 static void interface_minimize(GtkWidget *btn, gpointer user_data);
-static void interface_confirm_close(GtkWidget *btn, gpointer user_data);
+static void interface_confirm_close(GtkWidget *btn,GdkEvent  *event, gpointer user_data);
 
 #ifdef ENABLE_ECG_VIEW
 static void interface_show_ecg(
@@ -101,6 +101,11 @@ static void interface_show_analyzer_view(
 		GtkTreePath *path,
 		gpointer user_data);
 
+static void interface_show_general_settings(
+		NavigationMenu *menu,
+		GtkTreePath *path,
+		gpointer user_data);
+
 static void interface_hide_map_view(GtkWidget *widget, gpointer user_data);
 
 static void interface_hide_analyzer_view(GtkWidget *widget, gpointer user_data);
@@ -126,7 +131,7 @@ static void interface_start_activity(
 AppData *interface_create()
 {
 	AppData *app_data = NULL;
-
+	gboolean notify_user_data;
 	app_data = g_new0(AppData, 1);
 
 	if(!app_data)
@@ -141,18 +146,21 @@ AppData *interface_create()
 	app_data->program = HILDON_PROGRAM(hildon_program_get_instance());
 	g_set_application_name(_("eCoach"));
 
-	app_data->window = HILDON_WINDOW(hildon_window_new());
-	hildon_program_add_window(app_data->program, app_data->window);
+	//app_data->window = HILDON_WINDOW(hildon_window_new());
+	app_data->window = hildon_stackable_window_new ();
+
+
+	//hildon_program_add_window(app_data->program, app_data->window);
 	gtk_widget_set_name(GTK_WIDGET(app_data->window), "mainwindow");
 
-	gtk_window_fullscreen(GTK_WINDOW(app_data->window));
+	//gtk_window_fullscreen(GTK_WINDOW(app_data->window));
 
 	/* Parse styles */
 	gtk_rc_parse(RCFILE_PATH);
 
 	/* Initialize GConf helper */
 	interface_initialize_gconf(app_data);
-	
+
 	/* Initialize generic settings */
 	app_data->settings = settings_initialize(app_data->gconf_helper);
 
@@ -168,12 +176,7 @@ AppData *interface_create()
 			(GtkWindow *)app_data->window,
 			app_data->gconf_helper);
 
-	app_data->hrm_data = hrm_initialize(app_data->gconf_helper);
-	if(!app_data->hrm_data)
-	{
-		g_critical("hrm_initialize() failed");
-		return NULL;
-	}
+
 
 	interface_create_menu(app_data);
 
@@ -209,9 +212,9 @@ AppData *interface_create()
 			app_data->beat_detector,
 			app_data->osso);
 
-	app_data->map_view_tab_id = navigation_menu_append_page(
+	/*app_data->map_view_tab_id = navigation_menu_append_page(
 			app_data->navigation_menu,
-			app_data->map_view->main_widget);
+			app_data->map_view->main_widget);*/
 
 	g_signal_connect(G_OBJECT(app_data->map_view->btn_back),
 			"clicked",
@@ -226,28 +229,30 @@ AppData *interface_create()
 			GTK_WINDOW(app_data->window));
 
 	/* Create activity analyzer view */
-	app_data->analyzer_view = analyzer_view_new(
+	/*app_data->analyzer_view = analyzer_view_new(
 			GTK_WINDOW(app_data->window),
 			app_data->gconf_helper);
-
-	app_data->analyzer_view_tab_id = navigation_menu_append_page(
+*/
+	/*app_data->analyzer_view_tab_id = navigation_menu_append_page(
 			app_data->navigation_menu,
-			app_data->analyzer_view->main_widget);
-
+			app_data->analyzer_view->main_widget);*/
+/*
 	g_signal_connect(G_OBJECT(app_data->analyzer_view->btn_back),
 			"clicked",
 			G_CALLBACK(interface_hide_analyzer_view),
 			app_data);
-
+*/
 	/* Get the default folder for file operations */
+	g_mkdir("/home/user/MyDocs/eCoach/",755);
+
 	gconf_helper_add_key_string(
 			app_data->gconf_helper,
 			ECGC_DEFAULT_FOLDER,
-			"/media/",
+			"/home/user/MyDocs/eCoach/",
 			interface_default_folder_changed,
 			app_data,
 			NULL);
-	
+
 	/* Set default measuring units */
 	gconf_helper_add_key_bool(app_data->gconf_helper,USE_METRIC,TRUE,
 				  interface_measuring_units_changed,app_data,
@@ -257,15 +262,24 @@ AppData *interface_create()
 	gconf_helper_add_key_bool(app_data->gconf_helper,DISPLAY_ON,TRUE,
 				  interface_display_state_changed,app_data,
 				  NULL);
-	
+
 	/* Finalize the main window */
 	gtk_container_add(GTK_CONTAINER(app_data->window),
 			app_data->navigation_menu->main_widget);
-
-	g_signal_connect(G_OBJECT(app_data->window), "delete_event",
-			G_CALLBACK(gtk_main_quit), NULL);
+	
+	notify_user_data = gconf_helper_get_value_bool_with_default(app_data->gconf_helper,NOTIFY_USER,TRUE);
+	g_signal_connect(G_OBJECT(app_data->window), "delete-event",
+			G_CALLBACK(interface_confirm_close), app_data);
 
 	gtk_widget_show_all(GTK_WIDGET(app_data->window));
+	
+	if(!notify_user_data){
+	 
+	  GtkWidget *note = hildon_note_new_information(GTK_WINDOW(app_data->window),"This seems to be the first time you use eCoach.\n"
+	  "Please fill in the user data in the settings view");
+	  gtk_widget_show(note);
+	  gconf_helper_set_value_bool_simple(app_data->gconf_helper,NOTIFY_USER,TRUE);	  
+	}
 
 	return app_data;
 }
@@ -285,8 +299,8 @@ static void interface_create_menu(AppData *app_data)
 	/* Setup the navigation menu widget */
 	app_data->navigation_menu = navigation_menu_new();
 
-	navigation_menu_set_navigation_bar_background(app_data->navigation_menu,
-			GFXDIR "ec_titlebar_background.png");
+	//navigation_menu_set_navigation_bar_background(app_data->navigation_menu,
+	//		GFXDIR "ec_titlebar_background.png");
 
 	navigation_menu_set_default_button_background(app_data->navigation_menu,
 			GFXDIR "menu_generic_btn.png");
@@ -314,14 +328,6 @@ static void interface_create_menu(AppData *app_data)
 	navigation_menu_set_alignment(app_data->navigation_menu,
 			PANGO_ALIGN_CENTER);
 
-	g_signal_connect(G_OBJECT(app_data->navigation_menu->btn_close),
-			"clicked",
-			G_CALLBACK(interface_confirm_close), app_data);
-
-	g_signal_connect(G_OBJECT(app_data->navigation_menu->btn_minimize),
-			"clicked",
-			G_CALLBACK(interface_minimize), app_data);
-
 	/* Create the menus */
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
@@ -342,7 +348,7 @@ static void interface_create_menu(AppData *app_data)
 			FALSE);
 
 	/* TODO: Add old activities here */
-
+	/*
 	path_level_1 = navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			NULL,
@@ -352,6 +358,8 @@ static void interface_create_menu(AppData *app_data)
 			NULL,
 			TRUE);
 
+	  */
+	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
    			path_level_1,
@@ -360,7 +368,8 @@ static void interface_create_menu(AppData *app_data)
 			show_calculate_bmi,
 			app_data,
 			FALSE);
-
+	*/
+	/*
 	path_level_2 = navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
@@ -368,7 +377,7 @@ static void interface_create_menu(AppData *app_data)
 			GFXDIR "menu_max_heart_btn",
 			show_calculate_maxheartrate,
 			app_data,
-			TRUE);
+			TRUE);*/
 	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
@@ -388,8 +397,8 @@ static void interface_create_menu(AppData *app_data)
 			NULL,
 			FALSE);*/
 
-	gtk_tree_path_free(path_level_2);
-
+	//gtk_tree_path_free(path_level_2);
+/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
@@ -397,7 +406,7 @@ static void interface_create_menu(AppData *app_data)
 			GFXDIR "menu_target_heart_btn",
 			target_heart_rate_dialog_show,
 			app_data,
-			FALSE);
+			FALSE);*/
 	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
@@ -408,17 +417,19 @@ static void interface_create_menu(AppData *app_data)
 			NULL,
 			FALSE);
 	*/
-	gtk_tree_path_free(path_level_1);
+	//gtk_tree_path_free(path_level_1);
 
-	path_level_1 = navigation_menu_item_new_for_path(
+
+	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			NULL,
 			_("Settings"),
 			GFXDIR "menu_settings_btn",
-			NULL,
-			NULL,
-			TRUE);
+			interface_show_general_settings,
+			app_data,
+			FALSE);
 
+	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
@@ -445,8 +456,8 @@ static void interface_create_menu(AppData *app_data)
 			interface_show_about_dialog,
 			app_data,
 			FALSE);
-
-	gtk_tree_path_free(path_level_1);
+*/
+	//gtk_tree_path_free(path_level_1);
 
 #ifdef ENABLE_ECG_VIEW
 	navigation_menu_item_new_for_path(
@@ -492,7 +503,7 @@ static void interface_measuring_units_changed(
 	value = gconf_entry_get_value(entry);
 	use_metric = gconf_value_get_bool(value);
 	DEBUG_END();
-	
+
 }
 
 static void interface_display_state_changed(
@@ -528,7 +539,7 @@ static void interface_default_folder_changed(
 
 	value = gconf_entry_get_value(entry);
 	default_folder_name = gconf_value_get_string(value);
-	
+
 	activity_chooser_set_default_folder(
 			app_data->activity_chooser,
 			default_folder_name);
@@ -540,57 +551,67 @@ static void interface_default_folder_changed(
 	DEBUG_END();
 }
 
-static void interface_minimize(GtkWidget *btn, gpointer user_data)
-{
-	AppData *app_data = (AppData *)user_data;
 
-	g_return_if_fail(app_data != NULL);
-	DEBUG_BEGIN();
-
-	gtk_window_iconify(GTK_WINDOW(app_data->window));
-
-	DEBUG_END();
-}
-
-static void interface_confirm_close(GtkWidget *btn, gpointer user_data)
+static void interface_confirm_close(GtkWidget *btn,GdkEvent  *event, gpointer user_data)
 {
 	GtkWidget *dialog;
 	LocationGPSDControl *control;
-	
+	MapViewActivityState activity_state;
 	AppData *app_data = (AppData *)user_data;
 	gint result;
 
 	g_return_if_fail(app_data != NULL);
 	DEBUG_BEGIN();
-
-	dialog = hildon_note_new_confirmation(
-			GTK_WINDOW(app_data->window),
-			_("Do you really want to close the application?"));
-
-	result = gtk_dialog_run(GTK_DIALOG(dialog));
 	
-	gtk_widget_destroy(dialog);
-
-	if(result == GTK_RESPONSE_OK)
+	
+	activity_state = map_view_get_activity_state(app_data->map_view);	
+	if (activity_state == MAP_VIEW_ACTIVITY_STATE_STARTED ||
+	  activity_state == MAP_VIEW_ACTIVITY_STATE_PAUSED)
 	{
-		DBusConnection *conn;
-		conn = osso_get_dbus_connection(app_data->osso);
-		DBusMessage *message = NULL;
-		message = dbus_message_new_method_call( MAPTILELOADER_DBUS_SERVICE,
-                                            MAPTILELOADER_DBUS_OBJECT_PATH,
-                                            MAPTILELOADER_DBUS_INTERFACE,
-                                            "MaptileLoaderTerminate");
-		dbus_connection_send( conn, message,NULL);
-		dbus_message_unref(message);
-
+		dialog = hildon_note_new_confirmation(
+				GTK_WINDOW(app_data->window),
+		_("You are about to close eCoach but "
+		"there is currently an activity going on.\n"
+		  "Are you sure you want to close?"));
+		gtk_widget_show_all(dialog);
+		result = gtk_dialog_run(GTK_DIALOG(dialog));
+		gtk_widget_destroy(dialog);
+		if(result == GTK_RESPONSE_OK)
+		{
 		control = location_gpsd_control_get_default ();
 		location_gpsd_control_stop(control);
 		map_view_stop(app_data->map_view);
 		osso_deinitialize(app_data->osso);
 		gtk_main_quit();
-		
+		}
+	  
 	}
+	else
+	{
+		control = location_gpsd_control_get_default ();
+		location_gpsd_control_stop(control);
+		map_view_stop(app_data->map_view);
+		osso_deinitialize(app_data->osso);
+		gtk_main_quit();
+	}
+	  
+	
+		
+/*
+	dialog = hildon_note_new_confirmation(
+			GTK_WINDOW(app_data->window),
+			_("Do you really want to close the application?"));
 
+	result = gtk_dialog_run(GTK_DIALOG(dialog));
+
+	gtk_widget_destroy(dialog);
+
+	if(result == GTK_RESPONSE_OK)
+	{
+*/		
+/*
+	}
+*/
 	DEBUG_END();
 }
 
@@ -603,11 +624,11 @@ static void interface_show_map_view(
 
 	g_return_if_fail(app_data != NULL);
 	DEBUG_BEGIN();
-
+/*
 	navigation_menu_set_current_page(
 			app_data->navigation_menu,
 			app_data->map_view_tab_id);
-
+*/
 	map_view_show(app_data->map_view);
 
 	DEBUG_END();
@@ -623,15 +644,44 @@ static void interface_show_analyzer_view(
 	g_return_if_fail(app_data != NULL);
 	DEBUG_BEGIN();
 
-	navigation_menu_set_current_page(
-			app_data->navigation_menu,
-			app_data->analyzer_view_tab_id);
-
+	app_data->analyzer_view = analyzer_view_new(
+			GTK_WINDOW(app_data->window),
+			app_data->gconf_helper);
+	//navigation_menu_set_current_page(
+	//		app_data->navigation_menu,
+	//		app_data->analyzer_view_tab_id);
+	app_data->analyzer_view->activity_state = app_data->map_view->activity_state;
+	
 	analyzer_view_show(app_data->analyzer_view);
 
+	//gtk_container_add (GTK_CONTAINER (app_data->analyzer_view->win),
+          //             app_data->analyzer_view->vbox);
+
 	DEBUG_END();
 }
 
+static void interface_show_general_settings(
+		NavigationMenu *menu,
+		GtkTreePath *path,
+		gpointer user_data)
+{
+	AppData *app_data = (AppData *)user_data;
+
+	g_return_if_fail(app_data != NULL);
+	DEBUG_BEGIN();
+
+	app_data->general_settings = general_settings_new(
+			GTK_WINDOW(app_data->window),
+			app_data->gconf_helper,app_data->dbus_system);
+	general_settings_show(app_data->general_settings);
+
+	DEBUG_END();
+}
+
+
+
+
+
 static void interface_hide_map_view(GtkWidget *widget, gpointer user_data)
 {
 	AppData *app_data = (AppData *)user_data;
@@ -667,6 +717,8 @@ static void interface_show_about_dialog(
 	GtkWidget *dialog = NULL;
 	GtkWidget *vbox = NULL;
 	GtkWidget *hbox = NULL;
+	GtkWidget *pannable = NULL;
+	GtkWidget *cont = NULL;
 	GtkWidget *view = NULL;
 	GtkWidget *scrollbar = NULL;
 	GtkTextBuffer *buffer = NULL;
@@ -683,35 +735,39 @@ static void interface_show_about_dialog(
 			_("About eCoach"),
 			GTK_WINDOW(app_data->window),
 			GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
-			GTK_STOCK_OK,
-			GTK_RESPONSE_OK,
 			NULL);
 
 	vbox = GTK_DIALOG(dialog)->vbox;
 
 	text_about = g_strdup_printf(_(
-				"eCoach version %s Copyright (C) 2008 \n"
+				"eCoach version %s Copyright (C) 2009 \n"
 				"Jukka Alasalmi Sampo Savola\n"
 				"Kai Skiftesvik Veli-Pekka Haajanen\n"),
 				PACKAGE_VERSION);
 	lbl_about = gtk_label_new(text_about);
 	g_free(text_about);
 
+	pannable =  hildon_pannable_area_new();
+
 	gtk_box_pack_start(GTK_BOX(vbox), lbl_about, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-	view = gtk_text_view_new();
+	//view = gtk_text_view_new();
+
+	view = hildon_text_view_new();
+	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (pannable), view);
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);
-	gtk_widget_set_size_request(view, 720, 240);
+	//gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(view), FALSE);
+	gtk_widget_set_size_request(dialog, 800, 390);
 
 	desc = pango_font_description_from_string("Nokia Sans 14");
 	gtk_widget_modify_font(view, desc);
 	pango_font_description_free(desc);
 
-	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(view));
+	buffer = hildon_text_view_get_buffer(HILDON_TEXT_VIEW(view));
 
 	gtk_text_buffer_set_text(buffer, _(
 		"eCoach comes with ABSOLUTELY NO WARRANTY. This is "
@@ -1090,13 +1146,18 @@ static void interface_show_about_dialog(
 "library.  If this is what you want to do, use the GNU Library General\n"
 "Public License instead of this License.\n", -1);
 
-	gtk_box_pack_start(GTK_BOX(hbox), view, FALSE, FALSE, 0);
+	cont = gtk_table_new(1,1,TRUE);
+	gtk_widget_set_size_request(cont,
+			800,
+			240);
+	gtk_container_add (GTK_CONTAINER (cont),pannable);
+	gtk_box_pack_start(GTK_BOX(hbox), cont, FALSE, FALSE, 0);
 
-	scrollbar = gtk_vscrollbar_new(NULL);
-	gtk_widget_set_scroll_adjustments(view, NULL,
-			GTK_RANGE(scrollbar)->adjustment);
+	//scrollbar = gtk_vscrollbar_new(NULL);
+	//gtk_widget_set_scroll_adjustments(view, NULL,
+	//		GTK_RANGE(scrollbar)->adjustment);
 
-	gtk_box_pack_start(GTK_BOX(hbox), scrollbar, FALSE, FALSE, 0);
+	//gtk_box_pack_start(GTK_BOX(hbox), scrollbar, FALSE, FALSE, 0);
 
 	gtk_widget_show_all(dialog);
 
@@ -1159,7 +1220,6 @@ static void interface_start_activity(
 	DEBUG_BEGIN();
 
 	activity_state = map_view_get_activity_state(app_data->map_view);
-
 	if (activity_state == MAP_VIEW_ACTIVITY_STATE_STOPPED)
 	{
 		dialog = hildon_note_new_confirmation_add_buttons(
