@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2009 Sampo Savola,  Jukka Alasalmi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #ifndef _MAP_VIEW_H
 #define _MAP_VIEW_H
 
+ #ifdef __cplusplus
+ extern "C" {
+ #endif
 /* Configuration */
 #include "config.h"
 
@@ -38,14 +41,25 @@
 #include <location/location-gps-device.h>
 #include <location/location-gpsd-control.h>
 
+/* Hildon */
+#include <hildon/hildon.h>
+#include <gtk/gtkenums.h>
+#include <hildon/hildon-button.h>
+
+/*osm-gps-map*/
+
+#include "osm_gps_map/osm-gps-map.h"
 /* Osso */
 #include <libosso.h>
 
 /* Other modules */
+
 #include "beat_detect.h"
 #include "gconf_helper.h"
 #include "track.h"
 
+
+
 typedef struct _MapView MapView;
 typedef struct _MapViewGpsPoint MapViewGpsPoint;
 
@@ -86,8 +100,12 @@ struct _MapViewGpsPoint {
 
 struct _MapView {
 	GtkWindow *parent_window;	/**< Parent window		*/
+	GtkWidget *win;			/**Stackable window		*/
 	GtkWidget *main_widget;		/**< Main layout item		*/
 
+	GtkWidget *data_widget;
+	HildonAppMenu *menu;	 	/** Menu			*/
+
 	/* Buttons		*/
 	/*	General		*/
 	GtkWidget *btn_back;		/**< Leave view to background 	*/
@@ -104,7 +122,15 @@ struct _MapView {
 	GtkWidget *btn_map_scrl_down;	/**< Scroll the map down	*/
 	GtkWidget *btn_map_scrl_left;	/**< Scroll the map left	*/
 	GtkWidget *btn_map_scrl_right;	/**< Scroll the map right	*/
-
+	GdkPixbuf *zoom_in;		/** Zoom in			*/
+	GdkPixbuf *zoom_out;		/** Zoom out			*/
+	GtkWidget *map;
+	GdkPixbuf *map_btn;
+	GdkPixbuf *data_btn;
+	GdkPixbuf *rec_btn_selected;
+	GdkPixbuf *rec_btn_unselected;
+	GdkPixbuf *pause_btn_unselected;
+	GdkPixbuf *pause_btn_selected;
 	/* Info buttons		*/
 	GtkWidget *info_distance;	/**< Travelled distance		*/
 	GtkWidget *info_time;		/**< Elapsed time		*/
@@ -112,7 +138,8 @@ struct _MapView {
 	GtkWidget *info_avg_speed;	/**< Average speed		*/
 	GtkWidget *info_heart_rate;	/**< Heart rate			*/
 	GtkWidget *info_units;		/**< Distance units		*/
-
+	gboolean is_auto_center;
+	GtkWidget *info_speed_per_unit;
 	/* Progress indicators	*/
 	GtkWidget *indicator_1;		/**< "Progress indicator"	*/
 
@@ -136,7 +163,8 @@ struct _MapView {
 	LocationGPSDevice *gps_device;	/**< GPS device connection	*/
 	LocationGPSDControl
 		*gpsd_control;		/**< GPSD control		*/
-
+	gint	gps_update_interval;	/** GPS update interval		*/
+	guint   hide_buttons_timeout_id; /** timeout for hiding buttons */
 	MapViewMapWidgetState
 		map_widget_state;	/**< State of map widget	*/
 
@@ -151,10 +179,11 @@ struct _MapView {
 	struct timeval elapsed_time;	/**< Elapsed time		*/
 	struct timeval start_time;	/**< Time since previous start
 					      or continue		*/
+	gdouble mins,secs;	      /**for min_per_km  		*/		
 	guint activity_timer_id;	/**< Source id for g_timeout	*/
 
 	TrackHelper *track_helper;	/**< Track management		*/
-
+	
 	gchar *activity_name;
 	gchar *activity_comment;
 	gchar *file_name;
@@ -166,21 +195,69 @@ struct _MapView {
 	/* Icons */
 	GdkPixbuf *pxb_autocenter_on;	/**< Autocenter on		*/
 	GdkPixbuf *pxb_autocenter_off;	/**< Autocenter off		*/
+	gboolean show_min_per_km;
 
 	GdkPixbuf *pxb_hrm_status[MAP_VIEW_HRM_STATUS_COUNT];
 					/**< Heart rate status		*/
 
+
 	/*distance unit*/
-	
+
 	gboolean metric;
+	gboolean display_on;
+	gboolean fullscreen;
+	time_t start;
+	time_t end;
+	gdouble curr_speed;
+	OsmGpsMapSource_t map_provider ;
+
 	
-	
-	/* Temporary stuff	*/
 	gboolean point_added;
 	MapViewGpsPoint previous_added_point;
 	gdouble travelled_distance;
+	const char *friendly_name;
+	char *cachedir;
+	gboolean fullpath;
+	gint buttons_hide_timeout;
+	gboolean add_calendar;
+	gboolean gps_initialized;
+	gboolean first_location_point_added;
+	/* for data view */
+	GtkWidget *data_win;
+	GtkWidget *data_map_btn;
+	GtkWidget *data_data_btn;
+	GtkWidget *data_map_event;
+	GtkWidget *data_rec_selected_event;
+	GtkWidget *data_pause_selected_event;
+	GtkWidget *data_rec_unselected_event;
+	GtkWidget *data_pause_unselected_event;
+	 GtkWidget *data_rec_btn_unselected;
+	 GtkWidget *data_rec_btn_selected;
+	 GtkWidget *data_pause_btn_unselected;
+	 GtkWidget *data_pause_btn_selected;
+	 
+	 /*For personal data view */
+	 GtkWidget *personal_win;
+
 };
 
+typedef struct _MapPoint MapPoint;
+struct _MapPoint
+{
+  gfloat latitude;
+  gfloat longitude;
+};
+
+
+
+typedef struct _Point Point;
+struct _Point
+{
+    guint unitx;
+    guint unity;
+};
+
+
 /**
  * @brief Create a new map view.
  *
@@ -188,7 +265,7 @@ struct _MapView {
  * and connect the "clicked" signal of following buttons:
  * 	btn_back
  * 	btn_close
- * 
+ *
  * @param gconf_helper Pointer to #GConfHelperData
  * @param beat_detector Pointer to #BeatDetector
  */
@@ -226,7 +303,8 @@ gboolean map_view_setup_activity(
 		const gchar *activity_comment,
 		const gchar *file_name,
 		gint heart_rate_limit_low,
-		gint heart_rate_limit_high);
+		gint heart_rate_limit_high,
+		gboolean add_calendar);
 
 /**
  * @brief Call this when map view is shown.
@@ -249,4 +327,7 @@ void map_view_stop(MapView *self);
  */
 void map_view_clear_all(MapView *self);
 
+#ifdef __cplusplus
+ }
+ #endif
 #endif /* _MAP_VIEW_H */
